added sample for how-to-use pre-compiled kernels1. Corrected the exit output of kernel compilation by hipcc

2. Added sample which loads/run kernel binary during runtime?

Change-Id: I26ccaca1f844fee317592e26c9e654ce548b96a8
This commit is contained in:
Aditya Atluri
2016-08-31 13:56:07 -05:00
vanhempi 6754587ed2
commit 667ec7cbe2
6 muutettua tiedostoa jossa 178 lisäystä ja 1 poistoa
@@ -0,0 +1,9 @@
#include<hip_runtime.h>
__global__ void hello_world(hipLaunchParm lp, float *a, float *b)
{
int tx = hipThreadIdx_x;
b[tx] = a[tx];
}
int main(){}